<a id="mypy-boto3-iot"></a>

# mypy-boto3-iot

[![PyPI - mypy-boto3-iot](https://img.shields.io/pypi/v/mypy-boto3-iot.svg?color=blue)](https://pypi.org/project/mypy-boto3-iot)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-iot.svg?color=blue)](https://pypi.org/project/mypy-boto3-iot)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-iot?color=blue)](https://pypistats.org/packages/mypy-boto3-iot)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.IoT 1.18.47](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/iot.html#IoT)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.3.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-iot docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-iot](#mypy-boto3-iot)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `IoT` service.

```bash
python -m pip install boto3-stubs[iot]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[iot]` in your environment:
  `python -m pip install 'boto3-stubs[iot]'`

Both type checking and auto-complete should work for `IoT` service. No explicit
type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[iot]` in your environment:
  `python -m pip install 'boto3-stubs[iot]'`

Both type checking and auto-complete should work for `IoT` service. No explicit
type annotations required, write your `boto3` code as usual. Auto-complete can
be slow on big projects or if you have a lot of installed `boto3-stubs`
submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[iot]` in your environment:
  `python -m pip install 'boto3-stubs[iot]'`
- Run `mypy` as usual

Type checking should work for `IoT` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[iot]` in your environment:
  `python -m pip install 'boto3-stubs[iot]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `IoT` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`IoTClient` provides annotations for `boto3.client("iot")`.

```python
import boto3

from mypy_boto3_iot import IoTClient

client: IoTClient = boto3.client("iot")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: IoTClient = session.client("iot")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_iot.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_iot import IoTClient
from mypy_boto3_iot.paginator import (
    GetBehaviorModelTrainingSummariesPaginator,
    ListActiveViolationsPaginator,
    ListAttachedPoliciesPaginator,
    ListAuditFindingsPaginator,
    ListAuditMitigationActionsExecutionsPaginator,
    ListAuditMitigationActionsTasksPaginator,
    ListAuditSuppressionsPaginator,
    ListAuditTasksPaginator,
    ListAuthorizersPaginator,
    ListBillingGroupsPaginator,
    ListCACertificatesPaginator,
    ListCertificatesPaginator,
    ListCertificatesByCAPaginator,
    ListCustomMetricsPaginator,
    ListDetectMitigationActionsExecutionsPaginator,
    ListDetectMitigationActionsTasksPaginator,
    ListDimensionsPaginator,
    ListDomainConfigurationsPaginator,
    ListFleetMetricsPaginator,
    ListIndicesPaginator,
    ListJobExecutionsForJobPaginator,
    ListJobExecutionsForThingPaginator,
    ListJobTemplatesPaginator,
    ListJobsPaginator,
    ListMitigationActionsPaginator,
    ListOTAUpdatesPaginator,
    ListOutgoingCertificatesPaginator,
    ListPoliciesPaginator,
    ListPolicyPrincipalsPaginator,
    ListPrincipalPoliciesPaginator,
    ListPrincipalThingsPaginator,
    ListProvisioningTemplateVersionsPaginator,
    ListProvisioningTemplatesPaginator,
    ListRoleAliasesPaginator,
    ListScheduledAuditsPaginator,
    ListSecurityProfilesPaginator,
    ListSecurityProfilesForTargetPaginator,
    ListStreamsPaginator,
    ListTagsForResourcePaginator,
    ListTargetsForPolicyPaginator,
    ListTargetsForSecurityProfilePaginator,
    ListThingGroupsPaginator,
    ListThingGroupsForThingPaginator,
    ListThingPrincipalsPaginator,
    ListThingRegistrationTaskReportsPaginator,
    ListThingRegistrationTasksPaginator,
    ListThingTypesPaginator,
    ListThingsPaginator,
    ListThingsInBillingGroupPaginator,
    ListThingsInThingGroupPaginator,
    ListTopicRuleDestinationsPaginator,
    ListTopicRulesPaginator,
    ListV2LoggingLevelsPaginator,
    ListViolationEventsPaginator,
)

client: IoTClient = boto3.client("iot")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
get_behavior_model_training_summaries_paginator: GetBehaviorModelTrainingSummariesPaginator = client.get_paginator("get_behavior_model_training_summaries")
list_active_violations_paginator: ListActiveViolationsPaginator = client.get_paginator("list_active_violations")
list_attached_policies_paginator: ListAttachedPoliciesPaginator = client.get_paginator("list_attached_policies")
list_audit_findings_paginator: ListAuditFindingsPaginator = client.get_paginator("list_audit_findings")
list_audit_mitigation_actions_executions_paginator: ListAuditMitigationActionsExecutionsPaginator = client.get_paginator("list_audit_mitigation_actions_executions")
list_audit_mitigation_actions_tasks_paginator: ListAuditMitigationActionsTasksPaginator = client.get_paginator("list_audit_mitigation_actions_tasks")
list_audit_suppressions_paginator: ListAuditSuppressionsPaginator = client.get_paginator("list_audit_suppressions")
list_audit_tasks_paginator: ListAuditTasksPaginator = client.get_paginator("list_audit_tasks")
list_authorizers_paginator: ListAuthorizersPaginator = client.get_paginator("list_authorizers")
list_billing_groups_paginator: ListBillingGroupsPaginator = client.get_paginator("list_billing_groups")
list_ca_certificates_paginator: ListCACertificatesPaginator = client.get_paginator("list_ca_certificates")
list_certificates_paginator: ListCertificatesPaginator = client.get_paginator("list_certificates")
list_certificates_by_ca_paginator: ListCertificatesByCAPaginator = client.get_paginator("list_certificates_by_ca")
list_custom_metrics_paginator: ListCustomMetricsPaginator = client.get_paginator("list_custom_metrics")
list_detect_mitigation_actions_executions_paginator: ListDetectMitigationActionsExecutionsPaginator = client.get_paginator("list_detect_mitigation_actions_executions")
list_detect_mitigation_actions_tasks_paginator: ListDetectMitigationActionsTasksPaginator = client.get_paginator("list_detect_mitigation_actions_tasks")
list_dimensions_paginator: ListDimensionsPaginator = client.get_paginator("list_dimensions")
list_domain_configurations_paginator: ListDomainConfigurationsPaginator = client.get_paginator("list_domain_configurations")
list_fleet_metrics_paginator: ListFleetMetricsPaginator = client.get_paginator("list_fleet_metrics")
list_indices_paginator: ListIndicesPaginator = client.get_paginator("list_indices")
list_job_executions_for_job_paginator: ListJobExecutionsForJobPaginator = client.get_paginator("list_job_executions_for_job")
list_job_executions_for_thing_paginator: ListJobExecutionsForThingPaginator = client.get_paginator("list_job_executions_for_thing")
list_job_templates_paginator: ListJobTemplatesPaginator = client.get_paginator("list_job_templates")
list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
list_mitigation_actions_paginator: ListMitigationActionsPaginator = client.get_paginator("list_mitigation_actions")
list_ota_updates_paginator: ListOTAUpdatesPaginator = client.get_paginator("list_ota_updates")
list_outgoing_certificates_paginator: ListOutgoingCertificatesPaginator = client.get_paginator("list_outgoing_certificates")
list_policies_paginator: ListPoliciesPaginator = client.get_paginator("list_policies")
list_policy_principals_paginator: ListPolicyPrincipalsPaginator = client.get_paginator("list_policy_principals")
list_principal_policies_paginator: ListPrincipalPoliciesPaginator = client.get_paginator("list_principal_policies")
list_principal_things_paginator: ListPrincipalThingsPaginator = client.get_paginator("list_principal_things")
list_provisioning_template_versions_paginator: ListProvisioningTemplateVersionsPaginator = client.get_paginator("list_provisioning_template_versions")
list_provisioning_templates_paginator: ListProvisioningTemplatesPaginator = client.get_paginator("list_provisioning_templates")
list_role_aliases_paginator: ListRoleAliasesPaginator = client.get_paginator("list_role_aliases")
list_scheduled_audits_paginator: ListScheduledAuditsPaginator = client.get_paginator("list_scheduled_audits")
list_security_profiles_paginator: ListSecurityProfilesPaginator = client.get_paginator("list_security_profiles")
list_security_profiles_for_target_paginator: ListSecurityProfilesForTargetPaginator = client.get_paginator("list_security_profiles_for_target")
list_streams_paginator: ListStreamsPaginator = client.get_paginator("list_streams")
list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
list_targets_for_policy_paginator: ListTargetsForPolicyPaginator = client.get_paginator("list_targets_for_policy")
list_targets_for_security_profile_paginator: ListTargetsForSecurityProfilePaginator = client.get_paginator("list_targets_for_security_profile")
list_thing_groups_paginator: ListThingGroupsPaginator = client.get_paginator("list_thing_groups")
list_thing_groups_for_thing_paginator: ListThingGroupsForThingPaginator = client.get_paginator("list_thing_groups_for_thing")
list_thing_principals_paginator: ListThingPrincipalsPaginator = client.get_paginator("list_thing_principals")
list_thing_registration_task_reports_paginator: ListThingRegistrationTaskReportsPaginator = client.get_paginator("list_thing_registration_task_reports")
list_thing_registration_tasks_paginator: ListThingRegistrationTasksPaginator = client.get_paginator("list_thing_registration_tasks")
list_thing_types_paginator: ListThingTypesPaginator = client.get_paginator("list_thing_types")
list_things_paginator: ListThingsPaginator = client.get_paginator("list_things")
list_things_in_billing_group_paginator: ListThingsInBillingGroupPaginator = client.get_paginator("list_things_in_billing_group")
list_things_in_thing_group_paginator: ListThingsInThingGroupPaginator = client.get_paginator("list_things_in_thing_group")
list_topic_rule_destinations_paginator: ListTopicRuleDestinationsPaginator = client.get_paginator("list_topic_rule_destinations")
list_topic_rules_paginator: ListTopicRulesPaginator = client.get_paginator("list_topic_rules")
list_v2_logging_levels_paginator: ListV2LoggingLevelsPaginator = client.get_paginator("list_v2_logging_levels")
list_violation_events_paginator: ListViolationEventsPaginator = client.get_paginator("list_violation_events")
```

<a id="literals"></a>

### Literals

`mypy_boto3_iot.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_iot.literals import (
    AbortActionType,
    ActionTypeType,
    AggregationTypeNameType,
    AlertTargetTypeType,
    AuditCheckRunStatusType,
    AuditFindingSeverityType,
    AuditFrequencyType,
    AuditMitigationActionsExecutionStatusType,
    AuditMitigationActionsTaskStatusType,
    AuditNotificationTypeType,
    AuditTaskStatusType,
    AuditTaskTypeType,
    AuthDecisionType,
    AuthorizerStatusType,
    AutoRegistrationStatusType,
    AwsJobAbortCriteriaAbortActionType,
    AwsJobAbortCriteriaFailureTypeType,
    BehaviorCriteriaTypeType,
    CACertificateStatusType,
    CACertificateUpdateActionType,
    CannedAccessControlListType,
    CertificateModeType,
    CertificateStatusType,
    ComparisonOperatorType,
    ConfidenceLevelType,
    CustomMetricTypeType,
    DayOfWeekType,
    DetectMitigationActionExecutionStatusType,
    DetectMitigationActionsTaskStatusType,
    DeviceCertificateUpdateActionType,
    DimensionTypeType,
    DimensionValueOperatorType,
    DomainConfigurationStatusType,
    DomainTypeType,
    DynamicGroupStatusType,
    DynamoKeyTypeType,
    EventTypeType,
    FieldTypeType,
    FleetMetricUnitType,
    GetBehaviorModelTrainingSummariesPaginatorName,
    IndexStatusType,
    JobExecutionFailureTypeType,
    JobExecutionStatusType,
    JobStatusType,
    ListActiveViolationsPaginatorName,
    ListAttachedPoliciesPaginatorName,
    ListAuditFindingsPaginatorName,
    ListAuditMitigationActionsExecutionsPaginatorName,
    ListAuditMitigationActionsTasksPaginatorName,
    ListAuditSuppressionsPaginatorName,
    ListAuditTasksPaginatorName,
    ListAuthorizersPaginatorName,
    ListBillingGroupsPaginatorName,
    ListCACertificatesPaginatorName,
    ListCertificatesByCAPaginatorName,
    ListCertificatesPaginatorName,
    ListCustomMetricsPaginatorName,
    ListDetectMitigationActionsExecutionsPaginatorName,
    ListDetectMitigationActionsTasksPaginatorName,
    ListDimensionsPaginatorName,
    ListDomainConfigurationsPaginatorName,
    ListFleetMetricsPaginatorName,
    ListIndicesPaginatorName,
    ListJobExecutionsForJobPaginatorName,
    ListJobExecutionsForThingPaginatorName,
    ListJobTemplatesPaginatorName,
    ListJobsPaginatorName,
    ListMitigationActionsPaginatorName,
    ListOTAUpdatesPaginatorName,
    ListOutgoingCertificatesPaginatorName,
    ListPoliciesPaginatorName,
    ListPolicyPrincipalsPaginatorName,
    ListPrincipalPoliciesPaginatorName,
    ListPrincipalThingsPaginatorName,
    ListProvisioningTemplateVersionsPaginatorName,
    ListProvisioningTemplatesPaginatorName,
    ListRoleAliasesPaginatorName,
    ListScheduledAuditsPaginatorName,
    ListSecurityProfilesForTargetPaginatorName,
    ListSecurityProfilesPaginatorName,
    ListStreamsPaginatorName,
    ListTagsForResourcePaginatorName,
    ListTargetsForPolicyPaginatorName,
    ListTargetsForSecurityProfilePaginatorName,
    ListThingGroupsForThingPaginatorName,
    ListThingGroupsPaginatorName,
    ListThingPrincipalsPaginatorName,
    ListThingRegistrationTaskReportsPaginatorName,
    ListThingRegistrationTasksPaginatorName,
    ListThingTypesPaginatorName,
    ListThingsInBillingGroupPaginatorName,
    ListThingsInThingGroupPaginatorName,
    ListThingsPaginatorName,
    ListTopicRuleDestinationsPaginatorName,
    ListTopicRulesPaginatorName,
    ListV2LoggingLevelsPaginatorName,
    ListViolationEventsPaginatorName,
    LogLevelType,
    LogTargetTypeType,
    MessageFormatType,
    MitigationActionTypeType,
    ModelStatusType,
    OTAUpdateStatusType,
    PolicyTemplateNameType,
    ProtocolType,
    ReportTypeType,
    ResourceTypeType,
    ServerCertificateStatusType,
    ServiceTypeType,
    StatusType,
    TargetSelectionType,
    ThingConnectivityIndexingModeType,
    ThingGroupIndexingModeType,
    ThingIndexingModeType,
    TopicRuleDestinationStatusType,
    VerificationStateType,
    ViolationEventTypeType,
    ServiceName,
)

def check_value(value: AbortActionType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_iot.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_iot.type_defs import (
    AbortConfigTypeDef,
    AbortCriteriaTypeDef,
    AcceptCertificateTransferRequestRequestTypeDef,
    ActionTypeDef,
    ActiveViolationTypeDef,
    AddThingToBillingGroupRequestRequestTypeDef,
    AddThingToThingGroupRequestRequestTypeDef,
    AddThingsToThingGroupParamsTypeDef,
    AggregationTypeTypeDef,
    AlertTargetTypeDef,
    AllowedTypeDef,
    AssetPropertyTimestampTypeDef,
    AssetPropertyValueTypeDef,
    AssetPropertyVariantTypeDef,
    AssociateTargetsWithJobRequestRequestTypeDef,
    AssociateTargetsWithJobResponseTypeDef,
    AttachPolicyRequestRequestTypeDef,
    AttachPrincipalPolicyRequestRequestTypeDef,
    AttachSecurityProfileRequestRequestTypeDef,
    AttachThingPrincipalRequestRequestTypeDef,
    AttributePayloadTypeDef,
    AuditCheckConfigurationTypeDef,
    AuditCheckDetailsTypeDef,
    AuditFindingTypeDef,
    AuditMitigationActionExecutionMetadataTypeDef,
    AuditMitigationActionsTaskMetadataTypeDef,
    AuditMitigationActionsTaskTargetTypeDef,
    AuditNotificationTargetTypeDef,
    AuditSuppressionTypeDef,
    AuditTaskMetadataTypeDef,
    AuthInfoTypeDef,
    AuthResultTypeDef,
    AuthorizerConfigTypeDef,
    AuthorizerDescriptionTypeDef,
    AuthorizerSummaryTypeDef,
    AwsJobAbortConfigTypeDef,
    AwsJobAbortCriteriaTypeDef,
    AwsJobExecutionsRolloutConfigTypeDef,
    AwsJobExponentialRolloutRateTypeDef,
    AwsJobPresignedUrlConfigTypeDef,
    AwsJobRateIncreaseCriteriaTypeDef,
    AwsJobTimeoutConfigTypeDef,
    BehaviorCriteriaTypeDef,
    BehaviorModelTrainingSummaryTypeDef,
    BehaviorTypeDef,
    BillingGroupMetadataTypeDef,
    BillingGroupPropertiesTypeDef,
    BucketTypeDef,
    BucketsAggregationTypeTypeDef,
    CACertificateDescriptionTypeDef,
    CACertificateTypeDef,
    CancelAuditMitigationActionsTaskRequestRequestTypeDef,
    CancelAuditTaskRequestRequestTypeDef,
    CancelCertificateTransferRequestRequestTypeDef,
    CancelDetectMitigationActionsTaskRequestRequestTypeDef,
    CancelJobExecutionRequestRequestTypeDef,
    CancelJobRequestRequestTypeDef,
    CancelJobResponseTypeDef,
    CertificateDescriptionTypeDef,
    CertificateTypeDef,
    CertificateValidityTypeDef,
    CloudwatchAlarmActionTypeDef,
    CloudwatchLogsActionTypeDef,
    CloudwatchMetricActionTypeDef,
    CodeSigningCertificateChainTypeDef,
    CodeSigningSignatureTypeDef,
    CodeSigningTypeDef,
    ConfigurationTypeDef,
    ConfirmTopicRuleDestinationRequestRequestTypeDef,
    CreateAuditSuppressionRequestRequestTypeDef,
    CreateAuthorizerRequestRequestTypeDef,
    CreateAuthorizerResponseTypeDef,
    CreateBillingGroupRequestRequestTypeDef,
    CreateBillingGroupResponseTypeDef,
    CreateCertificateFromCsrRequestRequestTypeDef,
    CreateCertificateFromCsrResponseTypeDef,
    CreateCustomMetricRequestRequestTypeDef,
    CreateCustomMetricResponseTypeDef,
    CreateDimensionRequestRequestTypeDef,
    CreateDimensionResponseTypeDef,
    CreateDomainConfigurationRequestRequestTypeDef,
    CreateDomainConfigurationResponseTypeDef,
    CreateDynamicThingGroupRequestRequestTypeDef,
    CreateDynamicThingGroupResponseTypeDef,
    CreateFleetMetricRequestRequestTypeDef,
    CreateFleetMetricResponseTypeDef,
    CreateJobRequestRequestTypeDef,
    CreateJobResponseTypeDef,
    CreateJobTemplateRequestRequestTypeDef,
    CreateJobTemplateResponseTypeDef,
    CreateKeysAndCertificateRequestRequestTypeDef,
    CreateKeysAndCertificateResponseTypeDef,
    CreateMitigationActionRequestRequestTypeDef,
    CreateMitigationActionResponseTypeDef,
    CreateOTAUpdateRequestRequestTypeDef,
    CreateOTAUpdateResponseTypeDef,
    CreatePolicyRequestRequestTypeDef,
    CreatePolicyResponseTypeDef,
    CreatePolicyVersionRequestRequestTypeDef,
    CreatePolicyVersionResponseTypeDef,
    CreateProvisioningClaimRequestRequestTypeDef,
    CreateProvisioningClaimResponseTypeDef,
    CreateProvisioningTemplateRequestRequestTypeDef,
    CreateProvisioningTemplateResponseTypeDef,
    CreateProvisioningTemplateVersionRequestRequestTypeDef,
    CreateProvisioningTemplateVersionResponseTypeDef,
    CreateRoleAliasRequestRequestTypeDef,
    CreateRoleAliasResponseTypeDef,
    CreateScheduledAuditRequestRequestTypeDef,
    CreateScheduledAuditResponseTypeDef,
    CreateSecurityProfileRequestRequestTypeDef,
    CreateSecurityProfileResponseTypeDef,
    CreateStreamRequestRequestTypeDef,
    CreateStreamResponseTypeDef,
    CreateThingGroupRequestRequestTypeDef,
    CreateThingGroupResponseTypeDef,
    CreateThingRequestRequestTypeDef,
    CreateThingResponseTypeDef,
    CreateThingTypeRequestRequestTypeDef,
    CreateThingTypeResponseTypeDef,
    CreateTopicRuleDestinationRequestRequestTypeDef,
    CreateTopicRuleDestinationResponseTypeDef,
    CreateTopicRuleRequestRequestTypeDef,
    CustomCodeSigningTypeDef,
    DeleteAccountAuditConfigurationRequestRequestTypeDef,
    DeleteAuditSuppressionRequestRequestTypeDef,
    DeleteAuthorizerRequestRequestTypeDef,
    DeleteBillingGroupRequestRequestTypeDef,
    DeleteCACertificateRequestRequestTypeDef,
    DeleteCertificateRequestRequestTypeDef,
    DeleteCustomMetricRequestRequestTypeDef,
    DeleteDimensionRequestRequestTypeDef,
    DeleteDomainConfigurationRequestRequestTypeDef,
    DeleteDynamicThingGroupRequestRequestTypeDef,
    DeleteFleetMetricRequestRequestTypeDef,
    DeleteJobExecutionRequestRequestTypeDef,
    DeleteJobRequestRequestTypeDef,
    DeleteJobTemplateRequestRequestTypeDef,
    DeleteMitigationActionRequestRequestTypeDef,
    DeleteOTAUpdateRequestRequestTypeDef,
    DeletePolicyRequestRequestTypeDef,
    DeletePolicyVersionRequestRequestTypeDef,
    DeleteProvisioningTemplateRequestRequestTypeDef,
    DeleteProvisioningTemplateVersionRequestRequestTypeDef,
    DeleteRoleAliasRequestRequestTypeDef,
    DeleteScheduledAuditRequestRequestTypeDef,
    DeleteSecurityProfileRequestRequestTypeDef,
    DeleteStreamRequestRequestTypeDef,
    DeleteThingGroupRequestRequestTypeDef,
    DeleteThingRequestRequestTypeDef,
    DeleteThingTypeRequestRequestTypeDef,
    DeleteTopicRuleDestinationRequestRequestTypeDef,
    DeleteTopicRuleRequestRequestTypeDef,
    DeleteV2LoggingLevelRequestRequestTypeDef,
    DeniedTypeDef,
    DeprecateThingTypeRequestRequestTypeDef,
    DescribeAccountAuditConfigurationResponseTypeDef,
    DescribeAuditFindingRequestRequestTypeDef,
    DescribeAuditFindingResponseTypeDef,
    DescribeAuditMitigationActionsTaskRequestRequestTypeDef,
    DescribeAuditMitigationActionsTaskResponseTypeDef,
    DescribeAuditSuppressionRequestRequestTypeDef,
    DescribeAuditSuppressionResponseTypeDef,
    DescribeAuditTaskRequestRequestTypeDef,
    DescribeAuditTaskResponseTypeDef,
    DescribeAuthorizerRequestRequestTypeDef,
    DescribeAuthorizerResponseTypeDef,
    DescribeBillingGroupRequestRequestTypeDef,
    DescribeBillingGroupResponseTypeDef,
    DescribeCACertificateRequestRequestTypeDef,
    DescribeCACertificateResponseTypeDef,
    DescribeCertificateRequestRequestTypeDef,
    DescribeCertificateResponseTypeDef,
    DescribeCustomMetricRequestRequestTypeDef,
    DescribeCustomMetricResponseTypeDef,
    DescribeDefaultAuthorizerResponseTypeDef,
    DescribeDetectMitigationActionsTaskRequestRequestTypeDef,
    DescribeDetectMitigationActionsTaskResponseTypeDef,
    DescribeDimensionRequestRequestTypeDef,
    DescribeDimensionResponseTypeDef,
    DescribeDomainConfigurationRequestRequestTypeDef,
    DescribeDomainConfigurationResponseTypeDef,
    DescribeEndpointRequestRequestTypeDef,
    DescribeEndpointResponseTypeDef,
    DescribeEventConfigurationsResponseTypeDef,
    DescribeFleetMetricRequestRequestTypeDef,
    DescribeFleetMetricResponseTypeDef,
    DescribeIndexRequestRequestTypeDef,
    DescribeIndexResponseTypeDef,
    DescribeJobExecutionRequestRequestTypeDef,
    DescribeJobExecutionResponseTypeDef,
    DescribeJobRequestRequestTypeDef,
    DescribeJobResponseTypeDef,
    DescribeJobTemplateRequestRequestTypeDef,
    DescribeJobTemplateResponseTypeDef,
    DescribeMitigationActionRequestRequestTypeDef,
    DescribeMitigationActionResponseTypeDef,
    DescribeProvisioningTemplateRequestRequestTypeDef,
    DescribeProvisioningTemplateResponseTypeDef,
    DescribeProvisioningTemplateVersionRequestRequestTypeDef,
    DescribeProvisioningTemplateVersionResponseTypeDef,
    DescribeRoleAliasRequestRequestTypeDef,
    DescribeRoleAliasResponseTypeDef,
    DescribeScheduledAuditRequestRequestTypeDef,
    DescribeScheduledAuditResponseTypeDef,
    DescribeSecurityProfileRequestRequestTypeDef,
    DescribeSecurityProfileResponseTypeDef,
    DescribeStreamRequestRequestTypeDef,
    DescribeStreamResponseTypeDef,
    DescribeThingGroupRequestRequestTypeDef,
    DescribeThingGroupResponseTypeDef,
    DescribeThingRegistrationTaskRequestRequestTypeDef,
    DescribeThingRegistrationTaskResponseTypeDef,
    DescribeThingRequestRequestTypeDef,
    DescribeThingResponseTypeDef,
    DescribeThingTypeRequestRequestTypeDef,
    DescribeThingTypeResponseTypeDef,
    DestinationTypeDef,
    DetachPolicyRequestRequestTypeDef,
    DetachPrincipalPolicyRequestRequestTypeDef,
    DetachSecurityProfileRequestRequestTypeDef,
    DetachThingPrincipalRequestRequestTypeDef,
    DetectMitigationActionExecutionTypeDef,
    DetectMitigationActionsTaskStatisticsTypeDef,
    DetectMitigationActionsTaskSummaryTypeDef,
    DetectMitigationActionsTaskTargetTypeDef,
    DisableTopicRuleRequestRequestTypeDef,
    DomainConfigurationSummaryTypeDef,
    DynamoDBActionTypeDef,
    DynamoDBv2ActionTypeDef,
    EffectivePolicyTypeDef,
    ElasticsearchActionTypeDef,
    EnableIoTLoggingParamsTypeDef,
    EnableTopicRuleRequestRequestTypeDef,
    ErrorInfoTypeDef,
    ExplicitDenyTypeDef,
    ExponentialRolloutRateTypeDef,
    FieldTypeDef,
    FileLocationTypeDef,
    FirehoseActionTypeDef,
    FleetMetricNameAndArnTypeDef,
    GetBehaviorModelTrainingSummariesRequestRequestTypeDef,
    GetBehaviorModelTrainingSummariesResponseTypeDef,
    GetBucketsAggregationRequestRequestTypeDef,
    GetBucketsAggregationResponseTypeDef,
    GetCardinalityRequestRequestTypeDef,
    GetCardinalityResponseTypeDef,
    GetEffectivePoliciesRequestRequestTypeDef,
    GetEffectivePoliciesResponseTypeDef,
    GetIndexingConfigurationResponseTypeDef,
    GetJobDocumentRequestRequestTypeDef,
    GetJobDocumentResponseTypeDef,
    GetLoggingOptionsResponseTypeDef,
    GetOTAUpdateRequestRequestTypeDef,
    GetOTAUpdateResponseTypeDef,
    GetPercentilesRequestRequestTypeDef,
    GetPercentilesResponseTypeDef,
    GetPolicyRequestRequestTypeDef,
    GetPolicyResponseTypeDef,
    GetPolicyVersionRequestRequestTypeDef,
    GetPolicyVersionResponseTypeDef,
    GetRegistrationCodeResponseTypeDef,
    GetStatisticsRequestRequestTypeDef,
    GetStatisticsResponseTypeDef,
    GetTopicRuleDestinationRequestRequestTypeDef,
    GetTopicRuleDestinationResponseTypeDef,
    GetTopicRuleRequestRequestTypeDef,
    GetTopicRuleResponseTypeDef,
    GetV2LoggingOptionsResponseTypeDef,
    GroupNameAndArnTypeDef,
    HttpActionHeaderTypeDef,
    HttpActionTypeDef,
    HttpAuthorizationTypeDef,
    HttpContextTypeDef,
    HttpUrlDestinationConfigurationTypeDef,
    HttpUrlDestinationPropertiesTypeDef,
    HttpUrlDestinationSummaryTypeDef,
    ImplicitDenyTypeDef,
    IotAnalyticsActionTypeDef,
    IotEventsActionTypeDef,
    IotSiteWiseActionTypeDef,
    JobExecutionStatusDetailsTypeDef,
    JobExecutionSummaryForJobTypeDef,
    JobExecutionSummaryForThingTypeDef,
    JobExecutionSummaryTypeDef,
    JobExecutionTypeDef,
    JobExecutionsRolloutConfigTypeDef,
    JobProcessDetailsTypeDef,
    JobSummaryTypeDef,
    JobTemplateSummaryTypeDef,
    JobTypeDef,
    KafkaActionTypeDef,
    KeyPairTypeDef,
    KinesisActionTypeDef,
    LambdaActionTypeDef,
    ListActiveViolationsRequestRequestTypeDef,
    ListActiveViolationsResponseTypeDef,
    ListAttachedPoliciesRequestRequestTypeDef,
    ListAttachedPoliciesResponseTypeDef,
    ListAuditFindingsRequestRequestTypeDef,
    ListAuditFindingsResponseTypeDef,
    ListAuditMitigationActionsExecutionsRequestRequestTypeDef,
    ListAuditMitigationActionsExecutionsResponseTypeDef,
    ListAuditMitigationActionsTasksRequestRequestTypeDef,
    ListAuditMitigationActionsTasksResponseTypeDef,
    ListAuditSuppressionsRequestRequestTypeDef,
    ListAuditSuppressionsResponseTypeDef,
    ListAuditTasksRequestRequestTypeDef,
    ListAuditTasksResponseTypeDef,
    ListAuthorizersRequestRequestTypeDef,
    ListAuthorizersResponseTypeDef,
    ListBillingGroupsRequestRequestTypeDef,
    ListBillingGroupsResponseTypeDef,
    ListCACertificatesRequestRequestTypeDef,
    ListCACertificatesResponseTypeDef,
    ListCertificatesByCARequestRequestTypeDef,
    ListCertificatesByCAResponseTypeDef,
    ListCertificatesRequestRequestTypeDef,
    ListCertificatesResponseTypeDef,
    ListCustomMetricsRequestRequestTypeDef,
    ListCustomMetricsResponseTypeDef,
    ListDetectMitigationActionsExecutionsRequestRequestTypeDef,
    ListDetectMitigationActionsExecutionsResponseTypeDef,
    ListDetectMitigationActionsTasksRequestRequestTypeDef,
    ListDetectMitigationActionsTasksResponseTypeDef,
    ListDimensionsRequestRequestTypeDef,
    ListDimensionsResponseTypeDef,
    ListDomainConfigurationsRequestRequestTypeDef,
    ListDomainConfigurationsResponseTypeDef,
    ListFleetMetricsRequestRequestTypeDef,
    ListFleetMetricsResponseTypeDef,
    ListIndicesRequestRequestTypeDef,
    ListIndicesResponseTypeDef,
    ListJobExecutionsForJobRequestRequestTypeDef,
    ListJobExecutionsForJobResponseTypeDef,
    ListJobExecutionsForThingRequestRequestTypeDef,
    ListJobExecutionsForThingResponseTypeDef,
    ListJobTemplatesRequestRequestTypeDef,
    ListJobTemplatesResponseTypeDef,
    ListJobsRequestRequestTypeDef,
    ListJobsResponseTypeDef,
    ListMitigationActionsRequestRequestTypeDef,
    ListMitigationActionsResponseTypeDef,
    ListOTAUpdatesRequestRequestTypeDef,
    ListOTAUpdatesResponseTypeDef,
    ListOutgoingCertificatesRequestRequestTypeDef,
    ListOutgoingCertificatesResponseTypeDef,
    ListPoliciesRequestRequestTypeDef,
    ListPoliciesResponseTypeDef,
    ListPolicyPrincipalsRequestRequestTypeDef,
    ListPolicyPrincipalsResponseTypeDef,
    ListPolicyVersionsRequestRequestTypeDef,
    ListPolicyVersionsResponseTypeDef,
    ListPrincipalPoliciesRequestRequestTypeDef,
    ListPrincipalPoliciesResponseTypeDef,
    ListPrincipalThingsRequestRequestTypeDef,
    ListPrincipalThingsResponseTypeDef,
    ListProvisioningTemplateVersionsRequestRequestTypeDef,
    ListProvisioningTemplateVersionsResponseTypeDef,
    ListProvisioningTemplatesRequestRequestTypeDef,
    ListProvisioningTemplatesResponseTypeDef,
    ListRoleAliasesRequestRequestTypeDef,
    ListRoleAliasesResponseTypeDef,
    ListScheduledAuditsRequestRequestTypeDef,
    ListScheduledAuditsResponseTypeDef,
    ListSecurityProfilesForTargetRequestRequestTypeDef,
    ListSecurityProfilesForTargetResponseTypeDef,
    ListSecurityProfilesRequestRequestTypeDef,
    ListSecurityProfilesResponseTypeDef,
    ListStreamsRequestRequestTypeDef,
    ListStreamsResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTargetsForPolicyRequestRequestTypeDef,
    ListTargetsForPolicyResponseTypeDef,
    ListTargetsForSecurityProfileRequestRequestTypeDef,
    ListTargetsForSecurityProfileResponseTypeDef,
    ListThingGroupsForThingRequestRequestTypeDef,
    ListThingGroupsForThingResponseTypeDef,
    ListThingGroupsRequestRequestTypeDef,
    ListThingGroupsResponseTypeDef,
    ListThingPrincipalsRequestRequestTypeDef,
    ListThingPrincipalsResponseTypeDef,
    ListThingRegistrationTaskReportsRequestRequestTypeDef,
    ListThingRegistrationTaskReportsResponseTypeDef,
    ListThingRegistrationTasksRequestRequestTypeDef,
    ListThingRegistrationTasksResponseTypeDef,
    ListThingTypesRequestRequestTypeDef,
    ListThingTypesResponseTypeDef,
    ListThingsInBillingGroupRequestRequestTypeDef,
    ListThingsInBillingGroupResponseTypeDef,
    ListThingsInThingGroupRequestRequestTypeDef,
    ListThingsInThingGroupResponseTypeDef,
    ListThingsRequestRequestTypeDef,
    ListThingsResponseTypeDef,
    ListTopicRuleDestinationsRequestRequestTypeDef,
    ListTopicRuleDestinationsResponseTypeDef,
    ListTopicRulesRequestRequestTypeDef,
    ListTopicRulesResponseTypeDef,
    ListV2LoggingLevelsRequestRequestTypeDef,
    ListV2LoggingLevelsResponseTypeDef,
    ListViolationEventsRequestRequestTypeDef,
    ListViolationEventsResponseTypeDef,
    LogTargetConfigurationTypeDef,
    LogTargetTypeDef,
    LoggingOptionsPayloadTypeDef,
    MachineLearningDetectionConfigTypeDef,
    MetricDimensionTypeDef,
    MetricToRetainTypeDef,
    MetricValueTypeDef,
    MitigationActionIdentifierTypeDef,
    MitigationActionParamsTypeDef,
    MitigationActionTypeDef,
    MqttContextTypeDef,
    NonCompliantResourceTypeDef,
    OTAUpdateFileTypeDef,
    OTAUpdateInfoTypeDef,
    OTAUpdateSummaryTypeDef,
    OpenSearchActionTypeDef,
    OutgoingCertificateTypeDef,
    PaginatorConfigTypeDef,
    PercentPairTypeDef,
    PolicyTypeDef,
    PolicyVersionIdentifierTypeDef,
    PolicyVersionTypeDef,
    PresignedUrlConfigTypeDef,
    ProvisioningHookTypeDef,
    ProvisioningTemplateSummaryTypeDef,
    ProvisioningTemplateVersionSummaryTypeDef,
    PublishFindingToSnsParamsTypeDef,
    PutAssetPropertyValueEntryTypeDef,
    PutItemInputTypeDef,
    PutVerificationStateOnViolationRequestRequestTypeDef,
    RateIncreaseCriteriaTypeDef,
    RegisterCACertificateRequestRequestTypeDef,
    RegisterCACertificateResponseTypeDef,
    RegisterCertificateRequestRequestTypeDef,
    RegisterCertificateResponseTypeDef,
    RegisterCertificateWithoutCARequestRequestTypeDef,
    RegisterCertificateWithoutCAResponseTypeDef,
    RegisterThingRequestRequestTypeDef,
    RegisterThingResponseTypeDef,
    RegistrationConfigTypeDef,
    RejectCertificateTransferRequestRequestTypeDef,
    RelatedResourceTypeDef,
    RemoveThingFromBillingGroupRequestRequestTypeDef,
    RemoveThingFromThingGroupRequestRequestTypeDef,
    ReplaceDefaultPolicyVersionParamsTypeDef,
    ReplaceTopicRuleRequestRequestTypeDef,
    RepublishActionTypeDef,
    ResourceIdentifierTypeDef,
    ResponseMetadataTypeDef,
    RoleAliasDescriptionTypeDef,
    S3ActionTypeDef,
    S3DestinationTypeDef,
    S3LocationTypeDef,
    SalesforceActionTypeDef,
    ScheduledAuditMetadataTypeDef,
    SearchIndexRequestRequestTypeDef,
    SearchIndexResponseTypeDef,
    SecurityProfileIdentifierTypeDef,
    SecurityProfileTargetMappingTypeDef,
    SecurityProfileTargetTypeDef,
    ServerCertificateSummaryTypeDef,
    SetDefaultAuthorizerRequestRequestTypeDef,
    SetDefaultAuthorizerResponseTypeDef,
    SetDefaultPolicyVersionRequestRequestTypeDef,
    SetLoggingOptionsRequestRequestTypeDef,
    SetV2LoggingLevelRequestRequestTypeDef,
    SetV2LoggingOptionsRequestRequestTypeDef,
    SigV4AuthorizationTypeDef,
    SigningProfileParameterTypeDef,
    SnsActionTypeDef,
    SqsActionTypeDef,
    StartAuditMitigationActionsTaskRequestRequestTypeDef,
    StartAuditMitigationActionsTaskResponseTypeDef,
    StartDetectMitigationActionsTaskRequestRequestTypeDef,
    StartDetectMitigationActionsTaskResponseTypeDef,
    StartOnDemandAuditTaskRequestRequestTypeDef,
    StartOnDemandAuditTaskResponseTypeDef,
    StartSigningJobParameterTypeDef,
    StartThingRegistrationTaskRequestRequestTypeDef,
    StartThingRegistrationTaskResponseTypeDef,
    StatisticalThresholdTypeDef,
    StatisticsTypeDef,
    StepFunctionsActionTypeDef,
    StopThingRegistrationTaskRequestRequestTypeDef,
    StreamFileTypeDef,
    StreamInfoTypeDef,
    StreamSummaryTypeDef,
    StreamTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TaskStatisticsForAuditCheckTypeDef,
    TaskStatisticsTypeDef,
    TermsAggregationTypeDef,
    TestAuthorizationRequestRequestTypeDef,
    TestAuthorizationResponseTypeDef,
    TestInvokeAuthorizerRequestRequestTypeDef,
    TestInvokeAuthorizerResponseTypeDef,
    ThingAttributeTypeDef,
    ThingConnectivityTypeDef,
    ThingDocumentTypeDef,
    ThingGroupDocumentTypeDef,
    ThingGroupIndexingConfigurationTypeDef,
    ThingGroupMetadataTypeDef,
    ThingGroupPropertiesTypeDef,
    ThingIndexingConfigurationTypeDef,
    ThingTypeDefinitionTypeDef,
    ThingTypeMetadataTypeDef,
    ThingTypePropertiesTypeDef,
    TimeoutConfigTypeDef,
    TimestreamActionTypeDef,
    TimestreamDimensionTypeDef,
    TimestreamTimestampTypeDef,
    TlsContextTypeDef,
    TopicRuleDestinationConfigurationTypeDef,
    TopicRuleDestinationSummaryTypeDef,
    TopicRuleDestinationTypeDef,
    TopicRuleListItemTypeDef,
    TopicRulePayloadTypeDef,
    TopicRuleTypeDef,
    TransferCertificateRequestRequestTypeDef,
    TransferCertificateResponseTypeDef,
    TransferDataTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateAccountAuditConfigurationRequestRequestTypeDef,
    UpdateAuditSuppressionRequestRequestTypeDef,
    UpdateAuthorizerRequestRequestTypeDef,
    UpdateAuthorizerResponseTypeDef,
    UpdateBillingGroupRequestRequestTypeDef,
    UpdateBillingGroupResponseTypeDef,
    UpdateCACertificateParamsTypeDef,
    UpdateCACertificateRequestRequestTypeDef,
    UpdateCertificateRequestRequestTypeDef,
    UpdateCustomMetricRequestRequestTypeDef,
    UpdateCustomMetricResponseTypeDef,
    UpdateDeviceCertificateParamsTypeDef,
    UpdateDimensionRequestRequestTypeDef,
    UpdateDimensionResponseTypeDef,
    UpdateDomainConfigurationRequestRequestTypeDef,
    UpdateDomainConfigurationResponseTypeDef,
    UpdateDynamicThingGroupRequestRequestTypeDef,
    UpdateDynamicThingGroupResponseTypeDef,
    UpdateEventConfigurationsRequestRequestTypeDef,
    UpdateFleetMetricRequestRequestTypeDef,
    UpdateIndexingConfigurationRequestRequestTypeDef,
    UpdateJobRequestRequestTypeDef,
    UpdateMitigationActionRequestRequestTypeDef,
    UpdateMitigationActionResponseTypeDef,
    UpdateProvisioningTemplateRequestRequestTypeDef,
    UpdateRoleAliasRequestRequestTypeDef,
    UpdateRoleAliasResponseTypeDef,
    UpdateScheduledAuditRequestRequestTypeDef,
    UpdateScheduledAuditResponseTypeDef,
    UpdateSecurityProfileRequestRequestTypeDef,
    UpdateSecurityProfileResponseTypeDef,
    UpdateStreamRequestRequestTypeDef,
    UpdateStreamResponseTypeDef,
    UpdateThingGroupRequestRequestTypeDef,
    UpdateThingGroupResponseTypeDef,
    UpdateThingGroupsForThingRequestRequestTypeDef,
    UpdateThingRequestRequestTypeDef,
    UpdateTopicRuleDestinationRequestRequestTypeDef,
    ValidateSecurityProfileBehaviorsRequestRequestTypeDef,
    ValidateSecurityProfileBehaviorsResponseTypeDef,
    ValidationErrorTypeDef,
    ViolationEventAdditionalInfoTypeDef,
    ViolationEventOccurrenceRangeTypeDef,
    ViolationEventTypeDef,
    VpcDestinationConfigurationTypeDef,
    VpcDestinationPropertiesTypeDef,
    VpcDestinationSummaryTypeDef,
)

def get_structure() -> AbortConfigTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-iot` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-iot docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
